@@ -9,10 +9,12 @@ var os = require('os');
  */
 
 global.endpoint = "127.0.0.1";
-global.port = 8500
-global.secure = false
+global.port = 8500;
+global.secure = false;
+global.config_key = "git2consul/config"
 for (var i=2; i<process.argv.length; ++i) {
   if(process.argv[i] === '-s' || process.argv[i] === '--secure') global.secure = true
+
   if(process.argv[i] === '-e' || process.argv[i] === '--endpoint') {
     if(i+1 >= process.argv.length) {
       logger.error("No endpoint provided with --endpoint option");
@@ -21,10 +23,18 @@ for (var i=2; i<process.argv.length; ++i) {
     global.endpoint = process.argv[i+1];
   }
 
+  if(process.argv[i] === '-c' || process.argv[i] === '--config_key') {
+    if(i+1 >= process.argv.length) {
+      logger.error("No consul Key name provided with --config_key option");
+      process.exit(4);
+    }
+    global.config_key = process.argv[i+1];
+  }
+
   if(process.argv[i] === '-p' || process.argv[i] === '--port') {
     if(i+1 >= process.argv.length) {
       logger.error("No port provided with --port option");
-      process.exit(3);
+      process.exit(5);
     }
     global.port = process.argv[i+1];
   }
@@ -36,7 +46,7 @@ var config_reader = require('./config_reader.js');
  * Read config from a specially named Consul resource.  If the config was not seeded
  * (and this should be done using utils/config_seeder.js), git2consul will not boot.
  */
-config_reader.read(function(err, config) {
+config_reader.read({'key': 'git2consul/config'}, function(err, config) {
 
   if (err) return console.error(err);
 
